@@ -5,6 +5,7 @@ This module contains the tables.
 import webbrowser
 import shutil
 import os
+import logging
 from functools import partial
 
 from PyQt5.QtGui import QIcon, QCursor
@@ -20,21 +21,19 @@ from PyQt5.QtWidgets import (
 )
 
 import get_data
+import creator
 from dialogs import ConsoleDialog, ProgBarDialog
+from creator import CloningWorker
 from manage_pip import PipManager
-from creator import (
-    CloningWorker,
-    fix_requirements,
-    cmds,
-    opts
-)
+
+
+logger = logging.getLogger(__name__)
 
 
 
 class VenvTable(QTableView):
     """
-    The table that lists the virtual environments
-    found in the specified folder.
+    List the virtual environments found.
     """
     started = pyqtSignal()
     finished = pyqtSignal()
@@ -74,6 +73,10 @@ class VenvTable(QTableView):
         self.m_clone_repo_worker.finished.connect(self.progress_bar.close)
         self.m_clone_repo_worker.finished.connect(self.finish_info)
 
+        # perform a proper stop using quit() and wait()
+        self.thread.finished.connect(self.thread.quit)
+        self.thread.finished.connect(self.thread.wait)
+
 
     def contextMenuEvent(self, event):
         context_menu = QMenu(self)
@@ -221,11 +224,8 @@ class VenvTable(QTableView):
         context_menu.addMenu(install_sub_menu)
         install_sub_menu.addAction(install_packages_action)
         install_sub_menu.addAction(install_requires_action)
-
-        # editable sub menu
-        install_sub_menu.addMenu(editable_sub_menu)
-        editable_sub_menu.addAction(install_local_action)
-        editable_sub_menu.addAction(install_vsc_action)
+        install_sub_menu.addAction(install_local_action)
+        install_sub_menu.addAction(install_vsc_action)
 
         context_menu.addAction(save_requires_action)
 
@@ -247,7 +247,6 @@ class VenvTable(QTableView):
         """Test wether the Python version required is installed.
         """
         cfg_file = os.path.join(venv_path, "pyvenv.cfg")
-
         is_installed = get_data.get_pyvenv_cfg(cfg_file, "installed")
         version = get_data.get_pyvenv_cfg(cfg_file, "version")
         py_path = get_data.get_pyvenv_cfg(cfg_file, "py_path")
@@ -300,7 +299,7 @@ class VenvTable(QTableView):
             QMessageBox.information(
                 self,
                 "Info",
-                "This environment hasn't Pip installed."
+                "This environment has no Pip installed."
             )
             return False
         return False
@@ -308,12 +307,12 @@ class VenvTable(QTableView):
 
     def get_selected_item(self):
         """
-        Get the venv name of the selected row.
+        Get the item name of the selected row (index 0).
         """
-        listed_venvs = self.selectionModel().selectedRows()
-        for index in listed_venvs:
-            selected_venv = index.data()
-            return selected_venv
+        listed_items = self.selectionModel().selectedRows()
+        for index in listed_items:
+            selected_item = index.data()
+            return selected_item
 
 
     def upgrade_pip(self, event):
@@ -324,10 +323,10 @@ class VenvTable(QTableView):
 
         if self.has_pip(active_dir, venv):
             self.console.setWindowTitle("Updating Pip")
+            logger.info("Attempting to update Pip...")
 
-            print("[PROCESS]: Updating Pip to the latest version...")
             self.manager = PipManager(active_dir, venv)
-            self.manager.run_pip(cmds[0], [opts[0], "pip"])
+            self.manager.run_pip(creator.cmds[0], [creator.opts[0], "pip"])
             self.manager.started.connect(self.console.exec_)
 
             # display the updated output
@@ -361,12 +360,14 @@ class VenvTable(QTableView):
             file_path = file_name[0]
 
             if file_path != "":
-                fix_requirements(file_path)
-                print("[PROCESS]: Installing from requirements...")
+                creator.fix_requirements(file_path)
                 self.console.setWindowTitle("Installing from requirements")
+                logger.info("Installing from requirements...")
 
                 self.manager = PipManager(active_dir, venv)
-                self.manager.run_pip(cmds[0], [opts[1], f"'{file_path}'"])
+                self.manager.run_pip(
+                    creator.cmds[0], [creator.opts[1], f"'{file_path}'"]
+                )
                 self.manager.started.connect(self.console.exec_)
 
                 # display the updated output
@@ -383,19 +384,21 @@ class VenvTable(QTableView):
         active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
 
-        project_dir = QFileDialog.getExistingDirectory(
-            self,
-            "Select project directory"
-        )
-        project_name = os.path.basename(project_dir)
+        if self.has_pip(active_dir, venv):
+            project_dir = QFileDialog.getExistingDirectory(
+                self,
+                "Select project directory"
+            )
+            project_name = os.path.basename(project_dir)
 
-        if project_dir != "":
-            if self.has_pip(active_dir, venv):
-                print("[PROCESS]: Installing from local project path...")
+            if project_dir != "":
                 self.console.setWindowTitle(f"Installing {project_name}")
+                logger.info("Installing from local project path...")
 
                 self.manager = PipManager(active_dir, venv)
-                self.manager.run_pip(cmds[0], [opts[2], f"'{project_dir}'"])
+                self.manager.run_pip(
+                    creator.cmds[0], [creator.opts[2], f"'{project_dir}'"]
+                )
                 self.manager.started.connect(self.console.exec_)
 
                 # display the updated output
@@ -409,33 +412,26 @@ class VenvTable(QTableView):
     def install_vsc(self, event):
         """Install from a VSC repository.
         """
-        self.clone_process()
-
-
-    def clone_process(self):
-        """Clone the repository.
-        """
         active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
         venv_bin = os.path.join(active_dir, venv, "bin", "python")
 
-        url, ok = QInputDialog.getText(
-            self,
-            "Specify VSC project url",
-            "Enter url to repository:" + " " * 65
-        )
+        if self.has_pip(active_dir, venv):
+            url, ok = QInputDialog.getText(
+                self,
+                "Specify VSC project url",
+                "Enter url to repository:" + " " * 65
+            )
 
-        if url != "":
-            if self.has_pip(active_dir, venv):
+            if url != "":
                 project_name = os.path.basename(url)
                 project_url = f"git+{url}#egg={project_name}"
                 cmd = (
                     f"{venv_bin} -m pip install --no-cache-dir -e {project_url}"
                 )
-
-                print(f"[PROCESS]: Installing {project_name}...")
                 self.progress_bar.setWindowTitle(f"Installing {project_name}")
                 self.progress_bar.status_label.setText("Cloning repository...")
+                logger.info(f"Installing {project_name}...")
 
                 wrapper = partial(
                     self.m_clone_repo_worker.run_process, cmd
@@ -470,10 +466,11 @@ class VenvTable(QTableView):
             save_path = save_file[0]
 
             if save_path != "":
+                logger.info(f"Saving '{save_path}'...")
+
                 # write 'pip freeze' output to selected file
-                print(f"[PROCESS]: Saving '{save_path}'...")
                 self.manager = PipManager(active_dir, venv)
-                self.manager.run_pip(cmds[2], [">", save_path])
+                self.manager.run_pip(creator.cmds[2], [">", save_path])
 
                 # show an info message
                 message_txt = (f"Saved requirements in \n{save_path}")
@@ -489,9 +486,8 @@ class VenvTable(QTableView):
         if self.has_pip(active_dir, venv):
             self.console.setWindowTitle(f"Packages installed in:  {venv}")
 
-            print("[PROCESS]: Listing packages...")
             self.manager = PipManager(active_dir, f"'{venv}'")
-            self.manager.run_pip(cmds[style])
+            self.manager.run_pip(creator.cmds[style])
             self.manager.started.connect(self.console.exec_)
 
             # display the updated output
@@ -537,9 +533,12 @@ class VenvTable(QTableView):
                     self.progress_bar.status_label.setText(
                         "Installing pipdeptree..."
                     )
-                    print("[PROCESS]: Installing pipdeptree...")
+                    logger.info("Installing pipdeptree...")
+
                     self.manager = PipManager(active_dir, venv)
-                    self.manager.run_pip(cmds[0], [opts[0], "pipdeptree"])
+                    self.manager.run_pip(
+                        creator.cmds[0], [creator.opts[0], "pipdeptree"]
+                    )
                     self.manager.started.connect(self.progress_bar.exec_)
                     self.manager.finished.connect(self.progress_bar.close)
                     self.manager.process_stop()
@@ -575,12 +574,12 @@ class VenvTable(QTableView):
             )
             if msg_box_critical == QMessageBox.Yes:
                 shutil.rmtree(venv_path)
-                print(f"[PROCESS]: Successfully deleted '{venv_path}'")
+                logging.info(f"Successfully deleted '{venv_path}'")
                 self.refresh.emit()
 
 
 
-class ResultsTable(QTableView):
+class ResultsTable(VenvTable):
     """Contains the results from PyPI.
     """
     context_triggered = pyqtSignal()
@@ -592,9 +591,12 @@ class ResultsTable(QTableView):
             self.style().standardIcon(QStyle.SP_FileDialogInfoView)
         )
 
-
     def contextMenuEvent(self, event):
-        self.context_menu = QMenu(self)
+        context_menu = QMenu(self)
+
+        # pop up only if clicking on a row
+        if self.indexAt(event.pos()).isValid():
+            context_menu.popup(QCursor.pos())
 
         install_action = QAction(
             QIcon.fromTheme("software-install"),
@@ -602,7 +604,7 @@ class ResultsTable(QTableView):
             self,
             statusTip="Install module"
         )
-        self.context_menu.addAction(install_action)
+        context_menu.addAction(install_action)
         # connect to install_package() in InstallPackages() in wizard
         install_action.triggered.connect(
             lambda: self.context_triggered.emit()
@@ -614,24 +616,11 @@ class ResultsTable(QTableView):
             self,
             statusTip="Open on Python Package Index"
         )
-        self.context_menu.addAction(open_pypi_action)
+        context_menu.addAction(open_pypi_action)
         open_pypi_action.triggered.connect(
             lambda: self.open_on_pypi(event)
         )
 
-        # pop up only if clicking on a row
-        if self.indexAt(event.pos()).isValid():
-            self.context_menu.popup(QCursor.pos())
-
-
-    def get_selected_item(self):
-        """Get the venv name of the selected row.
-        """
-        listed_items = self.selectionModel().selectedRows()
-        for index in listed_items:
-            selected_item = index.data()
-            return selected_item
-
 
     def open_on_pypi(self, event):
         """
@@ -640,3 +629,59 @@ class ResultsTable(QTableView):
         """
         package = self.get_selected_item()
         webbrowser.open(f"pypi.org/project/{package}/#description")
+
+
+
+class InterpreterTable(VenvTable):
+    """
+    List the Python installs found.
+    """
+    drop_item = pyqtSignal()
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        self.delete_icon = QIcon(
+            self.style().standardIcon(QStyle.SP_TrashIcon)
+        )
+
+    def contextMenuEvent(self, event):
+        context_menu = QMenu(self)
+
+        # pop up only if clicking on a row
+        if self.indexAt(event.pos()).isValid():
+            context_menu.popup(QCursor.pos())
+
+        remove_py_action = QAction(
+            self.delete_icon,
+            "&Remove from list",
+            self,
+            statusTip="Remove this item from the table"
+        )
+        context_menu.addAction(remove_py_action)
+        remove_py_action.triggered.connect(
+            lambda: self.remove_python(event)
+        )
+
+
+    def remove_python(self, event):
+        """Remove a Python version from the table.
+        """
+        item = self.get_selected_item()
+
+        msg_box_warning = QMessageBox.warning(
+            self,
+            "Confirm",
+            "Remove this item from list.     \nAre you sure?",
+            QMessageBox.Yes | QMessageBox.Cancel
+        )
+        if msg_box_warning == QMessageBox.Yes:
+            with open(get_data.DB_FILE, "r") as f:
+                lines = f.readlines()
+            with open(get_data.DB_FILE, "w") as f:
+                for line in lines:
+                    if item not in line:
+                        f.write(line)
+
+            logging.info(f"Removed '{item}'' from database")
+            self.drop_item.emit()
