@@ -6,6 +6,7 @@ and setting up virtual environments.
 import sys
 import os
 import csv
+import logging
 from functools import partial
 from pathlib import Path
 
@@ -43,23 +44,17 @@ from PyQt5.QtWidgets import (
     QHeaderView,
     QDesktopWidget
 )
-import venvipy_rc  # pylint: disable=unused-import
 
+import venvipy_rc  # pylint: disable=unused-import
+import get_data
+import creator
 from dialogs import ProgBarDialog, ConsoleDialog
-from manage_pip import PipManager
 from tables import ResultsTable
-from get_data import (
-    get_package_infos,
-    get_python_version,
-    get_python_installs
-)
-from creator import (
-    CreationWorker,
-    fix_requirements,
-    random_zen_line,
-    cmds,
-    opts
-)
+from creator import CreationWorker
+from manage_pip import PipManager
+
+
+logger = logging.getLogger(__name__)
 
 
 
@@ -187,6 +182,9 @@ class BasicSettings(QWizardPage):
 
         # updated
         self.m_install_venv_worker.updatePipMsg.connect(self.update_pip_msg)
+        self.m_install_venv_worker.updatePipMsg.connect(
+            lambda: logger.info("Updating pip...")
+        )
 
         # finished
         self.m_install_venv_worker.finished.connect(self.progress_bar.close)
@@ -318,17 +316,14 @@ class BasicSettings(QWizardPage):
     def pop_combo_box(self):
         """Add the selected Python version to combo box.
         """
-        get_python_installs()
-        csv_file = os.path.expanduser("~/.venvipy/py-installs")
-
-        if os.path.isfile(csv_file):
-            with open(csv_file, newline="") as cf:
-                reader = csv.DictReader(cf, delimiter=",")
-                for info in reader:
-                    self.interpreter_combo_box.addItem(
-                        f'{info["PYTHON_VERSION"]}  ->  {info["PYTHON_PATH"]}',
-                        info["PYTHON_PATH"]
-                    )
+        get_data.ensure_dbfile()
+        with open(get_data.DB_FILE, newline="") as cf:
+            reader = csv.DictReader(cf, delimiter=",")
+            for info in reader:
+                self.interpreter_combo_box.addItem(
+                    f'{info["PYTHON_VERSION"]}  ->  {info["PYTHON_PATH"]}',
+                    info["PYTHON_PATH"]
+                )
 
 
     def select_python(self):
@@ -346,23 +341,16 @@ class BasicSettings(QWizardPage):
         bin_file = file_name[0]
 
         if bin_file != "":
-            custom_version = get_python_version(bin_file)
-            csv_file = os.path.expanduser("~/.venvipy/py-installs")
-            with open(csv_file, "a", newline="") as cf:
-                fields = ["PYTHON_VERSION", "PYTHON_PATH"]
-                writer = csv.DictWriter(
-                    cf, delimiter=",", quoting=csv.QUOTE_ALL, fieldnames=fields
-                )
-                writer.writerow({
-                    "PYTHON_VERSION": custom_version,
-                    "PYTHON_PATH": bin_file
-                })
+            get_data.add_python(bin_file)
+
             # clear combo box content and call pop_combo_box()
             self.interpreter_combo_box.clear()
             self.interpreter_combo_box.addItem("---")
             self.pop_combo_box()
             # also call pop_interpreter_table() method in venvi.MainWindow
             self.wizard().update_table.emit()
+            return bin_file
+        return ""
 
 
     def select_dir(self):
@@ -485,6 +473,7 @@ class InstallPackages(QWizardPage):
             "click next."
         )
 
+        self.console = ConsoleDialog()
 
         #]===================================================================[#
         #] PAGE CONTENT [#===================================================[#
@@ -569,7 +558,7 @@ class InstallPackages(QWizardPage):
         # run the installer if self.requirements holds a str
         if len(self.requirements) > 0:
             try:
-                fix_requirements(self.requirements)
+                creator.fix_requirements(self.requirements)
             except FileNotFoundError:
                 pass  # the gui will show an error message
             self.install_requirements()
@@ -580,17 +569,18 @@ class InstallPackages(QWizardPage):
         """
         self.setEnabled(False)
 
-        self.manager = PipManager(self.venv_location, f"'{self.venv_name}'")
-        self.console = ConsoleDialog()
-
-        self.console.setWindowTitle("Cloning environment")
+        self.console.setWindowTitle("Creating environment")
+        logger.info("Creating environment...")
 
         # open the console when recieving signal from manager
+        self.manager = PipManager(self.venv_location, f"'{self.venv_name}'")
         self.manager.started.connect(self.console.exec_)
 
         # start installing packages from requirements file
         #print(f"[PROCESS]: Installing packages from '{self.requirements}'")
-        self.manager.run_pip(cmds[0], [opts[1], f"'{self.requirements}'"])
+        self.manager.run_pip(
+            creator.cmds[0], [creator.opts[1], f"'{self.requirements}'"]
+        )
 
         # display the updated output
         self.manager.textChanged.connect(self.console.update_status)
@@ -613,7 +603,7 @@ class InstallPackages(QWizardPage):
 
         self.results_model.setRowCount(0)
 
-        for info in get_package_infos(search_item):
+        for info in get_data.get_package_infos(search_item):
             self.results_model.insertRow(0)
 
             for i, text in enumerate(
@@ -621,10 +611,10 @@ class InstallPackages(QWizardPage):
                 ):
                 self.results_model.setItem(0, i, QStandardItem(text))
 
-        if not get_package_infos(search_item):
-            #print(f"[PIP]: No matches for '{search_item}'")
-
-            QMessageBox.information(self,
+        if not get_data.get_package_infos(search_item):
+            logger.debug(f"No matches for '{search_item}'")
+            QMessageBox.information(
+                self,
                 "No result",
                 f"No result matching '{search_item}'.\n"
             )
@@ -646,18 +636,18 @@ class InstallPackages(QWizardPage):
         )
 
         if msg_box_question == QMessageBox.Yes:
-            self.manager = PipManager(
-                self.venv_location, f"'{self.venv_name}'"
-            )
-            self.console = ConsoleDialog()
             self.console.setWindowTitle(f"Installing {self.pkg}")
 
+            self.manager = PipManager(
+                self.venv_location,
+                f"'{self.venv_name}'"
+            )
             # open the console when recieving signal from manager
             self.manager.started.connect(self.console.exec_)
 
             # start installing the selected package
-            #print(f"[PROCESS]: Installing package '{self.pkg}'...")
-            self.manager.run_pip(cmds[0], [opts[0], self.pkg])
+            logger.info(f"Installing '{self.pkg}'...")
+            self.manager.run_pip(creator.cmds[0], [creator.opts[0], self.pkg])
 
             # display the updated output
             self.manager.textChanged.connect(self.console.update_status)
@@ -695,12 +685,12 @@ class InstallPackages(QWizardPage):
             save_path = save_file[0]
 
             if save_path != "":
-                print(f"[PROCESS]: Saving '{save_path}'...")
                 self.manager = PipManager(self.venv_location, self.venv_name)
-                self.manager.run_pip(cmds[2], [">", save_path])
+                self.manager.run_pip(creator.cmds[2], [">", save_path])
 
                 msg_txt = (f"Saved requirements in: \n{save_path}")
                 QMessageBox.information(self, "Saved", msg_txt)
+                logger.info(f"Saved '{save_path}'...")
                 self.wizard().next()
         else:
             self.wizard().next()
@@ -757,7 +747,7 @@ class FinalPage(QWizardPage):
         """
         Set lebel text with a random line from the Zen of Python.
         """
-        self.zen_line.setText(random_zen_line())
+        self.zen_line.setText(creator.random_zen_line())
 
 
     def initializePage(self):
@@ -799,4 +789,8 @@ def main():
 
 
 if __name__ == "__main__":
+
+    LOG_FORMAT = "%(levelname)s - %(message)s"
+    logging.basicConfig(level=logging.DEBUG, format=LOG_FORMAT)
+
     main()
